/*
    Copyright (C) 2005-2009  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <glib/gi18n.h>
#include "nntpgrab_automation.h"

void
nntpgrab_automation_import_nzb_file(NNTPGrabCore *core, NZB *nzbfile, const char *collection_name, char **warnings)
{
    GList *list;
    char *errmsg = NULL;

    list = nzbfile->files;

    if (warnings) {
        *warnings = NULL;
    }

    while (list) {
        NZBFile *file = list->data;

        if (!nntpgrab_schedular_add_task_to_queue(core, collection_name, file->subject, file->poster, file->stamp, file->filesize, file->groups, file->segments, &errmsg)) {
            if (warnings) {
                if (*warnings) {
                    char *tmp = g_strdup_printf("%s\n%s", *warnings, errmsg);
                    g_free(*warnings);
                    *warnings = tmp;
                } else {
                    *warnings = g_strdup_printf(_("File could not be added to the download queue:\n%s"), errmsg);
                }
                g_free(errmsg);
            }
        }

        list = g_list_next(list);
    }
}
