/*
    Copyright (C) 2005-2009  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _COLLECTIONS_H_
#define _COLLECTIONS_H_

#define MAX_NNTP_SERVERS    25

typedef struct _par2real_file {
    char real_filename[256];
    int num_blocks_found;
    int num_blocks_missing;
    gboolean blocks_found[65535];           // FIXME: What is the maximum number of possible PAR2 blocks?
} PAR2RealFile;

typedef struct _par2file {
    char filename[256];
    GList *real_files;                      // List containing PAR2RealFile pointers
    int num_blocks_found;
    int num_blocks_missing;
} PAR2File;

typedef struct _par2set {
    unsigned char set_id[16];
    guint64 blocksize;
    GList *par2_files;                      // List containing PAR2File pointers
    int total_num_blocks_found;
    int total_num_blocks_missing;
    int total_recovery_blocks_available;
} PAR2Set;

typedef struct _nntp_part {
    const char message_id[256];
    int size;
    int partnum;
    gboolean downloaded;
    gboolean now_downloading;
    gboolean servers_already_tried[MAX_NNTP_SERVERS];
} NNTPPart;

typedef struct _nntp_file {
    const char subject[256];
    const char poster[256];
    time_t stamp;
    guint64 file_size;
    guint64 file_size_remaining;
    int position;
    int numparts;
    int num_parts_downloaded;
    int num_parts_failed;
    GList *parts;
    GList *groups;
    gboolean file_is_downloading;
    gboolean file_is_downloaded;
    gboolean stop_flag;
    gboolean now_decoding;
    gboolean now_verifying;
    const char tmp_filename[256];
    const char real_filename[256];
    TaskState status;
    NNTPFileType file_type;
    int par2_startnum;
    int par2_endnum;
    int num_par2_blocks;
} NNTPFile;

typedef struct _nntp_collection {
    const char collection_name[256];
    gboolean now_repairing;
    guint64 total_size;
    guint64 total_size_remaining;
    GList *files;
    gboolean stop_flag;
    int position;
    GList *par2sets;                // This list contains PAR2Set pointers
} NNTPCollection;

#endif /* _COLLECTIONS_H */
