/*
    Copyright (C) 2005-2009  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <glib.h>
#include <string.h>
#if !GLIB_CHECK_VERSION (2,14,0)
#include <pcre.h>
#endif

#if !GLIB_CHECK_VERSION(2,14,0)
pcre *
nntpgrab_utils_regex_compile(const char *regex)
{
    const char *regex_errmsg = NULL;
    int regex_errpos;
    pcre *re;

    re = pcre_compile(regex, PCRE_DOTALL, &regex_errmsg, &regex_errpos, NULL);

    if (!re) {
        g_warning("pcre_compile FAILED: %s\n", regex_errmsg);
    }

    return re;
}

void
nntpgrab_utils_regex_free(pcre *re)
{
    pcre_free(re);
}

const char **
nntpgrab_utils_regex_match(pcre *re, const char *line)
{
    int ovector[60];
    const char **values = NULL;
    int num;

    num = pcre_exec(re, NULL, line, strlen(line), 0, 0, ovector, 60);
    if (num <= 0) {
        return NULL;
    }

    pcre_get_substring_list(line, ovector, num, &values);

    return values;
}

void
nntpgrab_utils_regex_matches_free(const char **matches)
{
    pcre_free_substring_list(matches);
}
#else
GRegex *
nntpgrab_utils_regex_compile(const char *regex)
{
    GRegex *re;
    GError *err = NULL;

    re = g_regex_new(regex, G_REGEX_DOTALL, 0, &err);
    if (!re) {
        g_warning(err->message);
        g_error_free(err);
        return NULL;
    }

    return re;
}

void
nntpgrab_utils_regex_free(GRegex *re)
{
    g_regex_unref (re);
}

const char **
nntpgrab_utils_regex_match(GRegex *re, const char *line)
{
    GMatchInfo *match_info;
    char **values = NULL;

    if (!g_regex_match(re, line, 0, &match_info)) {
        g_match_info_free (match_info);
        return NULL;
    }

    values = g_match_info_fetch_all((const GMatchInfo*) match_info);

    g_match_info_free (match_info);

    return (const char **) values;
}

void
nntpgrab_utils_regex_matches_free(const char **matches)
{
    g_strfreev((char **) matches);
}
#endif
