/*
    Copyright (C) 2005-2009  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "gui.h"
#include "config_gui.h"

G_MODULE_EXPORT void
on_chkConfigShowTrayIcon_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();

    opts.show_tray_icon = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));

    config_gui_set_opts(opts);
}

static void
config_display_changed(NNTPGrabCore *core)
{
    GtkWidget *chkConfigShowTrayIcon = nntpgrab_gui_base_get_widget("chkConfigShowTrayIcon");
    ConfigGUIOpts opts = config_gui_get_opts();

#if GTK_CHECK_VERSION(2,10,0)
    if (opts.show_tray_icon && !nntpgrab_gui_base_tray_icon_get_is_shown()) {
        nntpgrab_gui_base_tray_create();
    } else if (!opts.show_tray_icon && nntpgrab_gui_base_tray_icon_get_is_shown()) {
        nntpgrab_gui_base_tray_destroy();
    }
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkConfigShowTrayIcon), opts.show_tray_icon);
#endif
}

G_MODULE_EXPORT void
on_chkShowColumnProgress_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_progress = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

G_MODULE_EXPORT void
on_chkShowColumnSubject_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_subject = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

G_MODULE_EXPORT void
on_chkShowColumnPoster_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_poster = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

G_MODULE_EXPORT void
on_chkShowColumnNewsgroups_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_newsgroups = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

G_MODULE_EXPORT void
on_chkShowColumnFilesize_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_filesize = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

G_MODULE_EXPORT void
on_chkShowColumnFilesizeRemaining_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_filesize_remaining = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

G_MODULE_EXPORT void
on_chkShowColumnStamp_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_stamp = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

G_MODULE_EXPORT void
on_chkShowColumnTimeRemaining_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_time_remaining = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

G_MODULE_EXPORT void
on_chkShowColumnTimeToFinish_toggled(GtkWidget *caller)
{
    ConfigGUIOpts opts = config_gui_get_opts();
    opts.show_column_time_to_finish = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(caller));
    config_gui_set_opts(opts);
}

void
config_display_initialize(void)
{
#if !GTK_CHECK_VERSION(2,10,0)
    GtkWidget *vbox7 = get_widget("vbox7");
#endif
    GtkWidget *chkShowColumnProgress = nntpgrab_gui_base_get_widget("chkShowColumnProgress");
    GtkWidget *chkShowColumnSubject = nntpgrab_gui_base_get_widget("chkShowColumnSubject");
    GtkWidget *chkShowColumnPoster = nntpgrab_gui_base_get_widget("chkShowColumnPoster");
    GtkWidget *chkShowColumnNewsgroups = nntpgrab_gui_base_get_widget("chkShowColumnNewsgroups");
    GtkWidget *chkShowColumnFilesize = nntpgrab_gui_base_get_widget("chkShowColumnFilesize");
    GtkWidget *chkShowColumnFilesizeRemaining = nntpgrab_gui_base_get_widget("chkShowColumnFilesizeRemaining");
    GtkWidget *chkShowColumnStamp = nntpgrab_gui_base_get_widget("chkShowColumnStamp");
    GtkWidget *chkShowColumnTimeRemaining = nntpgrab_gui_base_get_widget("chkShowColumnTimeRemaining");
    GtkWidget *chkShowColumnTimeToFinish = nntpgrab_gui_base_get_widget("chkShowColumnTimeToFinish");
    ConfigGUIOpts opts = config_gui_get_opts();

#if !GTK_CHECK_VERSION(2,10,0)
    // There's no tray icon support on GTK versions earlier than 2.10.0
    gtk_widget_hide(vbox7);
#endif

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnProgress), G_CALLBACK (on_chkShowColumnProgress_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnProgress), opts.show_column_progress);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnProgress), G_CALLBACK (on_chkShowColumnProgress_toggled), NULL);

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnSubject), G_CALLBACK (on_chkShowColumnSubject_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnSubject), opts.show_column_subject);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnSubject), G_CALLBACK (on_chkShowColumnSubject_toggled), NULL);

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnPoster), G_CALLBACK (on_chkShowColumnPoster_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnPoster), opts.show_column_poster);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnPoster), G_CALLBACK (on_chkShowColumnPoster_toggled), NULL);

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnNewsgroups), G_CALLBACK (on_chkShowColumnNewsgroups_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnNewsgroups), opts.show_column_newsgroups);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnNewsgroups), G_CALLBACK (on_chkShowColumnNewsgroups_toggled), NULL);

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnFilesize), G_CALLBACK (on_chkShowColumnFilesize_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnFilesize), opts.show_column_filesize);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnFilesize), G_CALLBACK (on_chkShowColumnFilesize_toggled), NULL);

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnFilesizeRemaining), G_CALLBACK (on_chkShowColumnFilesizeRemaining_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnFilesizeRemaining), opts.show_column_filesize_remaining);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnFilesizeRemaining), G_CALLBACK (on_chkShowColumnFilesizeRemaining_toggled), NULL);

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnStamp), G_CALLBACK (on_chkShowColumnStamp_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnStamp), opts.show_column_stamp);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnStamp), G_CALLBACK (on_chkShowColumnStamp_toggled), NULL);

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnTimeRemaining), G_CALLBACK (on_chkShowColumnTimeRemaining_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnTimeRemaining), opts.show_column_time_remaining);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnTimeRemaining), G_CALLBACK (on_chkShowColumnTimeRemaining_toggled), NULL);

    g_signal_handlers_block_by_func (G_OBJECT (chkShowColumnTimeToFinish), G_CALLBACK (on_chkShowColumnTimeToFinish_toggled), NULL);
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkShowColumnTimeToFinish), opts.show_column_time_to_finish);
    g_signal_handlers_unblock_by_func (G_OBJECT (chkShowColumnTimeToFinish), G_CALLBACK (on_chkShowColumnTimeToFinish_toggled), NULL);

    g_signal_connect(config_gui_get_object(), "config_changed", G_CALLBACK(config_display_changed), NULL);
    config_display_changed(core);
}
