/*
    Copyright (C) 2005-2009  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <string.h>
#include <sys/types.h>
#ifdef WIN32
#include <winsock2.h>
#include <ws2tcpip.h>
#include <wspiapi.h>
#else
#include <unistd.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#endif
#include "gui.h"

#ifdef WIN32
#define CLOSE(x)    closesocket(x)
#else
#define CLOSE(x)    close(x)
#endif

gboolean
test_is_nntpgrab_server_already_running(void)
{
    int sock;
    char *str_port;
    struct addrinfo hints, *res, *ressave;
    int n;

    memset(&hints, 0, sizeof(struct addrinfo));

    hints.ai_family = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;

    str_port = g_strdup_printf("%i", 5423);
    n = getaddrinfo("localhost", str_port, &hints, &res);
    g_free(str_port);

    ressave = res;

    while (res) {
        sock = socket(res->ai_family, res->ai_socktype, res->ai_protocol);

#ifdef WIN32
        if ((sock == INVALID_SOCKET)) {
#else
        if ((sock == -1)) {
#endif
            // The socket couldn't be created
            res = res->ai_next;
            continue;
        }

        if (connect(sock, res->ai_addr, (int) res->ai_addrlen) == 0) {
            // Connection succesfull
            break;
        }

        CLOSE(sock);
        sock = -1;

        res = res->ai_next;
    }

    if (sock == -1) {
        freeaddrinfo(ressave);

        return FALSE;
    }

    freeaddrinfo(ressave);

    CLOSE(sock);

    return TRUE;
}
