/*
    Copyright (C) 2005-2009  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <glib-object.h>
#include "nntpgrab_plugin_schedular.h"
#include "schedular_plugin.h"

void
par2verify_thread_func(gpointer data, gpointer user_data)
{
    PAR2VerifyData *par2_data = (PAR2VerifyData*) data;
    SchedularPlugin *schedular = SCHEDULAR_PLUGIN(user_data);
    gboolean collection_is_downloaded = TRUE;
    PAR2RepairData *repair_data;
    GList *list;

    // Do we still need to verify?
    g_static_mutex_lock(&schedular->mutex);
    if (schedular->abort_flag || par2_data->file->stop_flag) {
        par2_data->file->now_verifying = FALSE;
        g_static_mutex_unlock(&schedular->mutex);
        g_slice_free(PAR2VerifyData, par2_data);
        return;
    }

    // TODO: Perform the verify here

    // Is everything downloaded?
    list = schedular->queue;
    while (list) {
        NNTPCollection *collection = (NNTPCollection*) list->data;

        if (collection == par2_data->collection) {
            GList *list2 = collection->files;

            while (list2) {
                NNTPFile *file = (NNTPFile*) list2->data;

                if (!file->file_is_downloaded) {
                    collection_is_downloaded = FALSE;
                    break;
                }

                list2 = g_list_next(list2);
            }
        }

        if (!collection_is_downloaded) {
            break;
        }

        list = g_list_next(list);
    }
    g_static_mutex_unlock(&schedular->mutex);

    if (!collection_is_downloaded) {
        g_slice_free(PAR2VerifyData, par2_data);
        return;
    }

    // All files downloaded, perform a repair
    repair_data = g_slice_new0(PAR2RepairData);
    repair_data->collection = par2_data->collection;
    repair_data->collection->now_repairing = TRUE;
    g_thread_pool_push(par2_data->poolPar2repair, repair_data, NULL);

    g_slice_free(PAR2VerifyData, par2_data);
}
